@@ -1229,17 +1229,23 @@ ready_callback_key_compare (gconstpointer a, gconstpointer b)
 		return 1;
 	}
 	if (callback_a->file == NULL) {
-		if (callback_a->callback.directory < callback_b->callback.directory) {
+		/* ANSI C doesn't allow ordered compares of function pointers, so we cast them to
+		 * normal pointers to make some overly pedantic compilers (*cough* HP-UX *cough*)
+		 * compile this. Of course, on any compiler where ordered function pointers actually
+		 * break this probably won't work, but at least it will compile on platforms where it
+		 * works, but stupid compilers won't let you use it.
+		 */
+		if ((void *)callback_a->callback.directory < (void *)callback_b->callback.directory) {
 			return -1;
 		}
-		if (callback_a->callback.directory > callback_b->callback.directory) {
+		if ((void *)callback_a->callback.directory > (void *)callback_b->callback.directory) {
 			return 1;
 		}
 	} else {
-		if (callback_a->callback.file < callback_b->callback.file) {
+		if ((void *)callback_a->callback.file < (void *)callback_b->callback.file) {
 			return -1;
 		}
-		if (callback_a->callback.file > callback_b->callback.file) {
+		if ((void *)callback_a->callback.file > (void *)callback_b->callback.file) {
 			return 1;
 		}
 	}
@@ -1691,12 +1697,14 @@ should_look_for_dot_directory_file (NautilusFile *file)
 
 	const char *schemes [] = {
 		"preferences:",
+		"preferences-all-users:",
 		"all-preferences:",
 		"system-settings:",
 		"server-settings:",
 		"favorites:",
 		"start-here:",
 		"applications:",
+		"applications-all-users:",
 		"all-applications:"
 	};
 
